﻿import numpy as np
import matplotlib.pyplot as plt

data = np.loadtxt('logistic.csv', delimiter=',', skiprows=1)    # 学習データ読み込み
x = data[:,0:2]                                                 # x1,x2データ
t = data[:,2]                                                   # 分類を示すラベル
stdized_x = (x - x.mean(axis=0)) / x.std(axis=0)                # 標準正規化
x0 = np.ones([stdized_x.shape[0], 1])                           # バイアス項作成

matrix_x = np.hstack([x0 , stdized_x])                          # 1, x1, x2の順
w = np.random.rand(3)                                           # 重み初期化
rate = 0.01                                                     # 学習率
loop = 200000                                                   # 更新回数

# 重み更新
for i in range(loop):

    sig = 1/(1 + np.exp(-np.dot(matrix_x, w)))                  # シグモイド関数
    w += rate * np.dot((t-sig) * sig * (1-sig) , matrix_x)      # 重み更新

print(round(-w[0]/w[2],2),',', round(-w[1]/w[2],2))             # y=ax+bのb,aの順で表示

# 描画
x_axis = np.linspace(start=-2,stop=2,num=100)   
plt.plot(stdized_x[t == 1, 0],stdized_x[t == 1, 1], '^')        # ラベルが1のデータプロット
plt.plot(stdized_x[t != 1, 0],stdized_x[t != 1, 1], 'o')        # ラベルが1以外のデータプロット
plt.plot(x_axis, -(w[0] + w[1] * x_axis)/w[2])                  # 境界線プロット
plt.grid(True)
plt.show()
